

def knowme():
    print('''Hi, I'm Shubham Mohanty
A passionate student, learner, science enthusiast from India.
    A school student interested in programming, robotics, arduino, computers, gamedev and rc building.
''')
   
    
